% =========================================================================
% file scelta_ic.m
%
% Scope: This function allows the selection of the appropriate recurrence 
%        formula in gaussq_new.m, given the exponents al and be of the
%        Jacobi weight function w(x)=(1-x)^al(1+x)^be (al,be>-1).
%
% Call: ic = scelta_ic(al,be)
%
% Input: al,be = exponents of the Jacobi weight w
%
% Output: ic = chosen recurrence formula
%              1 -> Legendre weight w(x)=1
%              2 -> 1st kind Chebyshev weight w(x)=1/sqrt(1-x^2)
%              3 -> 2nd kind Chebyshev weight w(x)=sqrt(1-x^2)
%              5 -> generic Jacobi weight w(x)=(1-x)^al(1+x)^be
%
% Notes: Useful for automating the selection of the recurrence formula used
%        when calling the function gaussq_new.m or class1.m.
%
% Last Update: 16/01/2025
% =========================================================================

function ic = scelta_ic(al,be)

    if al==0 && be==0
        ic=1;
    elseif al==-1/2 && be==-1/2
        ic=2;
    elseif al==1/2 && be==1/2
        ic=3;
    else
        ic=5;
    end
    
end