% -------------------------------------------------------------------------
% This script contains the numerical experiments described in the paper
% (refer to Subsection 4.1 for the details).
% To reproduce Example 1, set example = 1
% To reproduce Example 2, set example = 2
% To reproduce Example 3, set example = 3
%
% Last Update: 16/01/2025
% -------------------------------------------------------------------------

example = 1;

switch example
    case 1 
        rho=1; sig=1; al=0.5;  be=0.5; ga=0; de=0;
        mu1= -1/(2*pi);  mu2 = 1/pi;
        m=[4 8 16 32 64 128 256 512];
        y=linspace(-0.99,0.99,1000);
        fesatta = y'.*sin(y').*weight(ga,de,y');
    case 2
        rho=0.5; sig=0.5; al=0;  be=-0.25; ga=0.25; de=0.25;
        mu1= 1/2;  mu2 = 1/3;
        m=[4 8 16 32 64 128 256 512];
        y=linspace(-0.99,0.99,1000);
        [fesatta,~] = main_nystrom(1024,al,be,rho,sig,ga,de,mu1,mu2,y',example);
    case 3
        rho=3/5; sig=0; al=1/3; be=0; ga=0; de=4/5;
        mu1= 1/10;  mu2 = 1/12;
        m=[4 8 16 32 64 128 256 512];
        y=linspace(-0.99,0.99,1000);
        [fesatta,~] = main_nystrom(1024,al,be,rho,sig,ga,de,mu1,mu2,y',example);
end

co = zeros(length(m),1);
err = co;
for k=1:length(m)
    [f,c]=main_nystrom(m(k),al,be,rho,sig,ga,de,mu1,mu2,y',example);
    co(k)=c; % condition number
    err(k)=norm(fesatta-f,inf)./norm(fesatta,inf); % maximum relative error
end

switch example
    case 1
        % Table of results for Example 1
        for k=1:length(m)
            fprintf('%d \t & %.2e \t & %.2e \t',m(k),err(k),co(k))
            fprintf('\n')
        end
    case 2
        % Estimated order of convergence
        eoc = zeros(length(m)-1,1);
        for i=1:length(m)-1
            E1=err(i)./err(i+1);
            eoc(i)=log(E1)/log(2);
        end
        % Table of results for Example 2
        for k=1:length(m)
            if k<length(m)
                fprintf('%d \t & %.2e \t & %.2e \t & %.2e \t',m(k),err(k),co(k),eoc(k))
                fprintf('\n')
            elseif k==length(m)
                fprintf('%d \t & %.2e \t & %.2e \t',m(k),err(k),co(k))
                fprintf('\n')
            end
        end
        % Solution plot
        figure(1)
        plot(y,fesatta,'LineWidth',1.4);
        set(gca,'fontsize',14)
        xlabel('$y$','interpreter','latex')
        ylabel('$f(y)$','interpreter','latex')
    case 3
        % Estimated order of convergence
        eoc = zeros(length(m)-1,1);
        for i=1:length(m)-1
            E1=err(i)./err(i+1);
            eoc(i)=log(E1)/log(2);
        end
        % Table of results for Example 3
        for k=1:length(m)
            if k<length(m)
                fprintf('%d \t & %.2e \t & %.2e \t & %.2e \t',m(k),err(k),co(k),eoc(k))
                fprintf('\n')
            elseif k==length(m)
                fprintf('%d \t & %.2e \t & %.2e \t',m(k),err(k),co(k))
                fprintf('\n')
            end
        end
        % Error plot
        order = 2;
        figure(1)
        hh = loglog(m,[err 1./m'.^order],'o-');
        set(gca,'xtick',m)
        set(gca,'fontsize',14)
        xlabel('$m$','interpreter','latex')
        ylabel('$\varepsilon_{m}$','interpreter','latex')
        set(hh(2),'linestyle','--')
        set(hh(2),'marker','+')
        set(hh(2),'LineWidth',1.4)
        set(hh(1),'LineWidth',1.4)
        xlim([0,512])
        legend('numerical error','theoretical error')
end





 


