% -------------------------------------------------------------------------
% This script contains the numerical experiments described in the paper
% (refer to Subsection 5.1 for the details).
% To reproduce Example 4, set example = 1
% To reproduce Example 5, set example = 2
% To reproduce Example 6, set example = 3
%
% Last Update: 16/01/2025
% -------------------------------------------------------------------------

example = 1;

switch example
    case 1 
         al=0; be=0; rho=1; sig=0; ga=0; de=0; 
         mu= 1/10;  
         m=[4 8 16 32 64 128 256 512];
         y=linspace(-0.99,0.99,1000);
         fesatta = exp(y'+1).*weight(ga,de,y');
    case 2 
        al=-1/5;  be=0; rho=2/3; sig=1/3; ga=1/2; de=3/5; 
        mu= -1/17; 
        m=[4 8 16 32 64 128 256 512];
        y=linspace(-0.99,0.99,1000);
        [fesatta,~] = main_nystrom(1024,al,be,rho,sig,ga,de,mu,y',example);
    case 3 
        al=0;  be=-1/2; rho=1/3; sig=1/3; ga=1/5; de=1/5; 
        mu= -1/20; 
        m=[4 8 16 32 64 128 256 512];
        y=linspace(-0.99,0.99,1000);
        [fesatta,~] = main_nystrom(1024,al,be,rho,sig,ga,de,mu,y',example);
end

co = zeros(length(m),1);
err = co;
for k=1:length(m)
    [f,c]=main_nystrom(m(k),al,be,rho,sig,ga,de,mu,y',example);
    co(k)=c; % condition number
    err(k)=norm(fesatta-f,inf)./norm(fesatta,inf); % maximum relative error
end

switch example
    case 1
        % Table of results for Example 4
        for k=1:length(m)
            fprintf('%d \t & %.2e \t & %.2e \t',m(k),err(k),co(k))
            fprintf('\n')
        end
    case 2
        % Estimated order of convergence 
        eoc = zeros(length(m)-1,1);
        for i=1:length(m)-1
            E1=err(i)./err(i+1);
            eoc(i)=log(E1)/log(2);
        end
        % Table of results for Example 5
        for k=1:length(m)
            if k<length(m)
                fprintf('%d \t & %.2e \t & %.2e \t & %.2e \t',m(k),err(k),co(k),eoc(k))
                fprintf('\n')
            elseif k==length(m)
                fprintf('%d \t & %.2e \t & %.2e \t',m(k),err(k),co(k))
                fprintf('\n')
            end
        end
        % Solution plot 
        figure(1)
        plot(y,fesatta,'LineWidth',1.4);
        set(gca,'fontsize',14)
        xlabel('$y$','interpreter','latex')
        ylabel('$f(y)$','interpreter','latex')
     case 3
        % Estimated order of convergence 
        eoc = zeros(length(m)-1,1);
        for i=1:length(m)-1
            E1=err(i)./err(i+1);
            eoc(i)=log(E1)/log(2);
        end
        % Table of results for Example 6
        for k=1:length(m)
            if k<length(m)
                fprintf('%d \t & %.2e \t & %.2e \t & %.2e \t',m(k),err(k),co(k),eoc(k))
                fprintf('\n')
            elseif k==length(m)
                fprintf('%d \t & %.2e \t & %.2e \t',m(k),err(k),co(k))
                fprintf('\n')
            end
        end
        % Error plot
        order = 2;
        figure(1)
        hh = loglog(m,[err 1./m'.^order],'o-');
        set(gca,'xtick',m)
        set(gca,'fontsize',14)
        xlabel('$m$','interpreter','latex')
        ylabel('$\varepsilon_{m}$','interpreter','latex')
        set(hh(2),'linestyle','--')
        set(hh(2),'marker','+')
        set(hh(2),'LineWidth',1.4)
        set(hh(1),'LineWidth',1.4)
        xlim([0,512])
        legend('numerical error','theoretical error')
end





 


